
#ifndef AKONADI_KCAL_EXPORT_H
#define AKONADI_KCAL_EXPORT_H

#ifdef AKONADI_KCAL_STATIC_DEFINE
#  define AKONADI_KCAL_EXPORT
#  define AKONADI_KCAL_NO_EXPORT
#else
#  ifndef AKONADI_KCAL_EXPORT
#    ifdef akonadi_kcal
        /* We are building this library */
#      define AKONADI_KCAL_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define AKONADI_KCAL_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef AKONADI_KCAL_NO_EXPORT
#    define AKONADI_KCAL_NO_EXPORT 
#  endif
#endif

#ifndef AKONADI_KCAL_DEPRECATED
#  define AKONADI_KCAL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef AKONADI_KCAL_DEPRECATED_EXPORT
#  define AKONADI_KCAL_DEPRECATED_EXPORT AKONADI_KCAL_EXPORT AKONADI_KCAL_DEPRECATED
#endif

#ifndef AKONADI_KCAL_DEPRECATED_NO_EXPORT
#  define AKONADI_KCAL_DEPRECATED_NO_EXPORT AKONADI_KCAL_NO_EXPORT AKONADI_KCAL_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define AKONADI_KCAL_NO_DEPRECATED
#endif

#endif
